@@ -24,7 +24,7 @@
 #include <ac/stddef.h>
 #include <ac/string.h>
 #include <ac/errno.h>
-#include <signal.h>
+#include <ac/signal.h>
 
 #include <cache.h>
 #include <error_intl.h>
