@@ -23,8 +23,6 @@
 #ifndef COMMON_AC_WCHAR_H
 #define COMMON_AC_WCHAR_H
 
-#include <config.h>
-
 /*
  * From the ``believe it or not'' category: The Dec Alpha OSF/1
  * <wchar.h> includes <time.h>, but we need to make sure our own
@@ -34,6 +32,11 @@
 #include <ac/time.h>
 #endif
 
+/*
+ * Cygwin's wchar.h has a missing size_t dependency, so include that first.
+ */
+#include <ac/stddef.h>
+
 #ifdef HAVE_WCHAR_H
 #include <wchar.h>
 #else
