@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -207,7 +207,7 @@ split()
 	str_hash_ty	idx;
 
 	/*
-	 * get the list to be split across buckets 
+	 * get the list to be split across buckets
 	 */
 	p = hash_table[hash_split];
 	hash_table[hash_split] = 0;
@@ -262,8 +262,8 @@ split()
  *	C string.
  *
  * RETURNS
- *	string_ty * - a pointer to a string in dynamic memory.  Use str_free when
- *	finished with.
+ *	string_ty * - a pointer to a string in dynamic memory.
+ *	Use str_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
@@ -289,8 +289,8 @@ str_from_c(s)
  *	characters.  No null terminator is assumed.
  *
  * RETURNS
- *	string_ty * - a pointer to a string in dynamic memory.  Use str_free when
- *	finished with.
+ *	string_ty * - a pointer to a string in dynamic memory.
+ *	Use str_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
@@ -370,8 +370,8 @@ str_n_from_c(s, length)
  *	The str_copy function is used to make a copy of a string.
  *
  * RETURNS
- *	string_ty * - a pointer to a string in dynamic memory.  Use str_free when
- *	finished with.
+ *	string_ty * - a pointer to a string in dynamic memory.
+ *	Use str_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
@@ -562,8 +562,8 @@ str_field(s, sep, fldnum)
  *	The "%S" specifier is used to mean a ``string_ty *'' string.
  *
  * RETURNS
- *	string_ty * - a pointer to a string in dynamic memory.  Use str_free when
- *	finished with.
+ *	string_ty * - a pointer to a string in dynamic memory.
+ *	Use str_free when finished with.
  */
 
 
