@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -407,7 +407,7 @@ execute(scp, arg)
 		/* NOTREACHED */
 		sub_context_delete(scp2);
 	}
-	
+
 	/*
 	 * scan the variables
 	 */
@@ -499,7 +499,11 @@ execute(scp, arg)
 		scp2 = sub_context_new();
 		sub_var_set(scp2, "Name", "%S", s3);
 		sub_var_set(scp2, "Message", "%s", gettext(the_error));
-		fatal_intl(scp2, i18n("substitution $${$name} failed: $message"));
+		fatal_intl
+		(
+			scp2,
+			i18n("substitution $${$name} failed: $message")
+		);
 		/* NOTREACHED */
 		sub_context_delete(scp2);
 		str_free(s3);
@@ -642,7 +646,7 @@ dollar(scp)
 	switch (c)
 	{
 	case '0': case '1': case '2': case '3': case '4':
-	case '5': case '6': case '7': case '8': case '9': 
+	case '5': case '6': case '7': case '8': case '9':
 		for (;;)
 		{
 			collect(&tmp, c);
@@ -671,12 +675,12 @@ dollar(scp)
 	case 'f': case 'g': case 'h': case 'i': case 'j':
 	case 'k': case 'l': case 'm': case 'n': case 'o':
 	case 'p': case 'q': case 'r': case 's': case 't':
-	case 'u': case 'v': case 'w': case 'x': case 'y': case 'z': 
+	case 'u': case 'v': case 'w': case 'x': case 'y': case 'z':
 	case 'A': case 'B': case 'C': case 'D': case 'E':
 	case 'F': case 'G': case 'H': case 'I': case 'J':
 	case 'K': case 'L': case 'M': case 'N': case 'O':
 	case 'P': case 'Q': case 'R': case 'S': case 'T':
-	case 'U': case 'V': case 'W': case 'X': case 'Y': case 'Z': 
+	case 'U': case 'V': case 'W': case 'X': case 'Y': case 'Z':
 		for (;;)
 		{
 			collect(&tmp, c);
@@ -688,15 +692,15 @@ dollar(scp)
 			case 'k': case 'l': case 'm': case 'n': case 'o':
 			case 'p': case 'q': case 'r': case 's': case 't':
 			case 'u': case 'v': case 'w': case 'x': case 'y':
-			case 'z': 
+			case 'z':
 			case 'A': case 'B': case 'C': case 'D': case 'E':
 			case 'F': case 'G': case 'H': case 'I': case 'J':
 			case 'K': case 'L': case 'M': case 'N': case 'O':
 			case 'P': case 'Q': case 'R': case 'S': case 'T':
 			case 'U': case 'V': case 'W': case 'X': case 'Y':
-			case 'Z': 
+			case 'Z':
 			case '0': case '1': case '2': case '3': case '4':
-			case '5': case '6': case '7': case '8': case '9': 
+			case '5': case '6': case '7': case '8': case '9':
 			case '_': case '-':
 				continue;
 
@@ -732,7 +736,11 @@ dollar(scp)
 				sub_context_ty	*scp2;
 
 				scp2 = sub_context_new();
-				fatal_intl(scp2, i18n("unterminated $${} substitution"));
+				fatal_intl
+				(
+					scp2,
+					i18n("unterminated $${} substitution")
+				);
 				/* NOTREACHED */
 				sub_context_delete(scp2);
 				break;
@@ -1001,7 +1009,7 @@ subst(scp, s)
 		error_intl
 		(
 			scp2,
-			i18n("in substitution \"$message\" variable \"$name\" unused")
+		  i18n("in substitution \"$message\" variable \"$name\" unused")
 		);
 		sub_context_delete(scp2);
 		str_free(tmp);
@@ -1026,7 +1034,7 @@ subst(scp, s)
 		fatal_intl
 		(
 			scp2,
-			i18n("in substitution \"$message\" found unused variables")
+		     i18n("in substitution \"$message\" found unused variables")
 		);
 		/* NOTREACHED */
 		str_free(tmp);
@@ -1334,4 +1342,4 @@ sub_context_errno_get(scp)
 	if (scp->errno_sequester == 0)
 		scp->errno_sequester = errno;
 	return scp->errno_sequester;
-}	
+}
