@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,8 @@ symtab_alloc(size)
 	stp->hash_cutover_mask = stp->hash_cutover - 1;
 	stp->hash_cutover_split_mask = (stp->hash_cutover * 2) - 1;
 	stp->hash_load = 0;
-	stp->hash_table = mem_alloc(stp->hash_modulus * sizeof(symtab_row_ty *));
+	stp->hash_table =
+		mem_alloc(stp->hash_modulus * sizeof(symtab_row_ty *));
 	for (j = 0; j < stp->hash_modulus; ++j)
 		stp->hash_table[j] = 0;
 	trace(("return %08lX;\n", (long)stp));
@@ -70,7 +71,7 @@ symtab_free(stp)
 		{
 			symtab_row_ty	*rp;
 
-			rp = *rpp; 
+			rp = *rpp;
 			*rpp = rp->overflow;
 			if (stp->reap)
 				stp->reap(rp->data);
@@ -113,7 +114,7 @@ split(stp)
 	str_hash_ty	index;
 
 	/*
-	 * get the list to be split across buckets 
+	 * get the list to be split across buckets
 	 */
 	trace(("split(stp = %08lX)\n{\n"/*}*/, (long)stp));
 	p = stp->hash_table[stp->hash_split];
@@ -276,7 +277,14 @@ symtab_query_fuzzy(stp, key, key_used)
 	best_result = 0;
 	best_key = 0;
 
-	symtab_query_fuzzy_inner(stp, key, &best_weight, &best_key, &best_result);
+	symtab_query_fuzzy_inner
+	(
+		stp,
+		key,
+		&best_weight,
+		&best_key,
+		&best_result
+	);
 
 	if (key_used && best_key)
 		*key_used = best_key;
