@@ -36,7 +36,6 @@ struct symtab_row_ty
 typedef struct symtab_ty symtab_ty;
 struct symtab_ty
 {
-	symtab_ty	*chain;
 	void		(*reap)_((void *));
 	symtab_row_ty	**hash_table;
 	str_hash_ty	hash_modulus;
@@ -51,6 +50,7 @@ symtab_ty *symtab_alloc _((int));
 void symtab_free _((symtab_ty *));
 void *symtab_query _((symtab_ty *, string_ty *));
 void *symtab_query_fuzzy _((symtab_ty *, string_ty *, string_ty **));
+void *symtab_query_fuzzyN _((symtab_ty **, size_t, string_ty *, string_ty **));
 void symtab_assign _((symtab_ty *, string_ty *, void *));
 void symtab_assign_push _((symtab_ty *, string_ty *, void *));
 void symtab_delete _((symtab_ty *, string_ty *));
