@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1994, 1997-1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@ struct method_ty
 	int (*magic)_((struct archive_file_ty *));
 	int (*advance)_((struct archive_file_ty *));
 	int (*name_compare)_((struct archive_file_ty *, string_ty *));
-	int (*stat)_((struct archive_file_ty *, struct stat *));
+	int (*do_stat)_((struct archive_file_ty *, struct stat *));
 	int (*utime)_((struct archive_file_ty *, struct utimbuf *));
 	void (*close)_((struct archive_file_ty *));
 };
@@ -1264,7 +1264,7 @@ archive_file_stat(afp, member, st)
 	 */
 	trace(("found\n"));
 	memset(st, 0, sizeof(*st));
-	if (afp->method->stat(afp, st))
+	if (afp->method->do_stat(afp, st))
 		goto done;
 
 	/*
