@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,17 +23,12 @@
 #ifndef COOK_BUILTIN_PATHNAME_H
 #define COOK_BUILTIN_PATHNAME_H
 
-#include <main.h>
+#include <builtin/private.h>
 
-struct string_list_ty; /* existence */
-struct expr_position_ty; /* existence */
-struct opcode_context_ty; /* existence */
-
-int builtin_dir _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
-int builtin_entryname _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
-int builtin_pathname _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
+extern builtin_ty builtin_dir;
+extern builtin_ty builtin_dirname;
+extern builtin_ty builtin_entryname;
+extern builtin_ty builtin_notdir;
+extern builtin_ty builtin_pathname;
 
 #endif /* COOK_BUILTIN_PATHNAME_H */
