@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -160,7 +160,14 @@ interpret(result, arg, pp, ocp)
 		if (start >= s->str_length)
 			s2 = str_from_c("");
 		else if (end > s->str_length)
-			s2 = str_n_from_c(s->str_text + start, s->str_length - start);
+		{
+			s2 =
+				str_n_from_c
+				(
+					s->str_text + start,
+					s->str_length - start
+				);
+		}
 		else
 			s2 = str_n_from_c(s->str_text + start, length);
 		trace(("s2 = \"%s\";\n", s2->str_text));
