@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -238,7 +238,8 @@ cook_mtime_oldest(ocp, path, depth_p, max_fp_depth)
 	time_t		result;
 	long		bogus;
 
-	trace(("cook_mtime_oldest(path = \"%s\", max = %ld)\n{\n"/*}*/, path->str_text, max_fp_depth));
+	trace(("cook_mtime_oldest(path = \"%s\", max = %ld)\n{\n"/*}*/,
+		path->str_text, max_fp_depth));
 	if (!depth_p)
 		depth_p = &bogus;
 	if (path->str_text[0] == '/')
@@ -282,7 +283,8 @@ cook_mtime_oldest(ocp, path, depth_p, max_fp_depth)
 				continue;
 			}
 
-			trace(("mtime(\"%s\") was %ld\n", s2->str_text, (long)t));
+			trace(("mtime(\"%s\") was %ld\n",
+				s2->str_text, (long)t));
 
 			/* File found */
 			if (!prv_fp)
@@ -319,7 +321,11 @@ cook_mtime_oldest(ocp, path, depth_p, max_fp_depth)
 			(
 				fp
 			&&
-				str_equal(fp->fingerprint, prv_fp->fingerprint)
+				str_equal
+				(
+					fp->contents_fingerprint,
+					prv_fp->contents_fingerprint
+				)
 			)
 			{
 				/* Deeper version is same as shallow one */
@@ -418,7 +424,8 @@ cook_mtime_newest(ocp, path, depth_p, max_fp_depth)
 				continue;
 			}
 
-			trace(("mtime(\"%s\") was %ld\n", s2->str_text, (long)t));
+			trace(("mtime(\"%s\") was %ld\n",
+				s2->str_text, (long)t));
 
 			/* File found */
 			if (!prv_fp)
@@ -456,7 +463,11 @@ cook_mtime_newest(ocp, path, depth_p, max_fp_depth)
 			(
 				fp
 			&&
-				str_equal(fp->fingerprint, prv_fp->fingerprint)
+				str_equal
+				(
+					fp->contents_fingerprint,
+					prv_fp->contents_fingerprint
+				)
 			)
 			{
 				/* Deeper version is same as shallow one */
