@@ -25,7 +25,7 @@
 
 #include <ac/stddef.h>
 #include <ac/stdarg.h>
-#include <stdio.h>
+#include <ac/stdio.h>
 
 #include <builtin.h>
 #include <cook.h>
