@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -173,7 +173,7 @@ fp_find_record(path_a)
 		 * DO NOT set main_stp->reap
 		 * as this will be done by fp_subdir_delete
 		 */
-		quit_handler(fp_find_flush);
+		quit_handler_prio(fp_find_flush);
 	}
 	path_r = os_relative_if_possible(path_a);
 	p = symtab_query(main_stp, path_r);
@@ -379,7 +379,10 @@ fp_find_flush()
 	fp_subdir_ty	*sdp;
 
 	if (!option_test(OPTION_FINGERPRINT_WRITE))
+	{
+		trace(("no fp write\n"));
 		return;
+	}
 
 	/*
 	 * Write out all of the known subdirectories, except dot.
