@@ -172,8 +172,9 @@ fp_record_update(this, fp)
 {
 	trace(("fp_record_update(this = %08lX, fp = %08lX)\n{\n",
 		(long)this, (long)fp));
-	if (!this->exists || !fp_value_equal(&this->value, fp))
+	if (!this->exists || !fp_value_equal_all(&this->value, fp))
 	{
+		trace(("need to update\n"));
 		this->exists = 1;
 		fp_subdir_dirty_notify(this->parent, this->filename);
 		fp_value_copy(&this->value, fp);
