@@ -341,13 +341,21 @@ fp_value_write(this, key, fp)
 
 /*
  * NAME
- *	fubar
+ *	fp_value_equal
  *
  * SYNOPSIS
- *	void fubar(void);
+ *	void fp_value_equal(void);
  *
  * DESCRIPTION
- *	The fubar function is used to
+ *	The fp_value_equal function is used to compare two fp_value_ty
+ *	structures for equality.
+ *
+ *	The ingredients_fingerprint is not compared.  This is because
+ *	the principal use of this function is to determine if a file
+ *	has changed.
+ *
+ * RETURNS
+ *	int; zero if they are not equal, non-zero if they are equal.
  */
 
 int
@@ -365,3 +373,38 @@ fp_value_equal(v1, v2)
 		v1->oldest == v2->oldest
 	);
 }
+
+
+/*
+ * NAME
+ *	fp_value_equal_all
+ *
+ * SYNOPSIS
+ *	void fp_value_equal_all(void);
+ *
+ * DESCRIPTION
+ *	The fp_value_equal_all function is used to compare two fp_value_ty
+ *	structures for equality.  The principal use of this function is to
+ *	determine if the fingerprint cache has changed and needs writing.
+ *
+ * RETURNS
+ *	int; zero if they are not equal, non-zero if they are equal.
+ */
+
+int
+fp_value_equal_all(v1, v2)
+	const fp_value_ty *v1;
+	const fp_value_ty *v2;
+{
+	return
+	(
+		str_equal(v1->contents_fingerprint, v2->contents_fingerprint)
+	&&
+		str_equal(v1->ingredients_fingerprint,
+			v2->ingredients_fingerprint)
+	&&
+		v1->newest == v2->newest
+	&&
+		v1->oldest == v2->oldest
+	);
+}
