@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -75,17 +75,31 @@ static table_ty table[] =
 	{ "no-forced",		RF_FORCE_OFF,	RF_FORCE,		},
 	{ "noforced",		RF_FORCE_OFF,	RF_FORCE,		},
 	{ "gate-before-ingredients", RF_GATEFIRST, RF_GATEFIRST_OFF,	},
-	{ "gate-first",		RF_GATEFIRST,	  RF_GATEFIRST_OFF,	}, /* undocumented, for compatibility only */
-	{ "no-gate-first",	RF_GATEFIRST_OFF, RF_GATEFIRST,		}, /* undocumented, for compatibility only */
+
+	/* undocumented, for compatibility only */
+	{ "gate-first",		RF_GATEFIRST,	  RF_GATEFIRST_OFF,	},
+	/* undocumented, for compatibility only */
+	{ "no-gate-first",	RF_GATEFIRST_OFF, RF_GATEFIRST,		},
+
 	{ "gate-after-ingredients", RF_GATEFIRST_OFF, RF_GATEFIRST,	},
-	{ "implicit-ingredients", RF_IMPLICIT_ALLOWED, RF_IMPLICIT_ALLOWED_OFF,	},
-	{ "explicit-ingredients", RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
+	{ "implicit-ingredients",
+		RF_IMPLICIT_ALLOWED, RF_IMPLICIT_ALLOWED_OFF,	},
+	{ "explicit-ingredients",
+		RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
 	{ "implicit-allowed",	RF_IMPLICIT_ALLOWED, RF_IMPLICIT_ALLOWED_OFF, },
-	{ "no-implicit-ingredients", RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
-	{ "no-implicit-allowed", RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
+	{ "no-implicit-ingredients",
+		RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
+	{ "no-implicit-allowed",
+		RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
 	{ "explicit-required",	RF_IMPLICIT_ALLOWED_OFF, RF_IMPLICIT_ALLOWED, },
-	{ "include-cooked-warning", RF_INCLUDE_COOKED_WARNING, RF_INCLUDE_COOKED_WARNING_OFF, },
-	{ "no-include-cooked-warning", RF_INCLUDE_COOKED_WARNING_OFF, RF_INCLUDE_COOKED_WARNING, },
+	{ "include-cooked-warning",
+		RF_INCLUDE_COOKED_WARNING, RF_INCLUDE_COOKED_WARNING_OFF, },
+	{ "no-include-cooked-warning",
+		RF_INCLUDE_COOKED_WARNING_OFF, RF_INCLUDE_COOKED_WARNING, },
+	{ "ingredients-fingerprint",
+		RF_INGREDIENTS_FINGERPRINT, RF_INGREDIENTS_FINGERPRINT_OFF, },
+	{ "no-ingredients-fingerprint",
+		RF_INGREDIENTS_FINGERPRINT_OFF, RF_INGREDIENTS_FINGERPRINT, },
 	{ "match-mode-cook",	RF_MATCH_MODE_COOK, RF_MATCH_MODE_REGEX, },
 	{ "match-mode-regex",	RF_MATCH_MODE_REGEX, RF_MATCH_MODE_COOK, },
 	{ "meter",		RF_METER,	RF_METER_OFF,		},
@@ -95,7 +109,7 @@ static table_ty table[] =
 	{ "no-mkdir",		RF_MKDIR_OFF,	RF_MKDIR,		},
 	{ "nomkdir",		RF_MKDIR_OFF,	RF_MKDIR,		},
 	{ "precious",		RF_PRECIOUS,	RF_PRECIOUS_OFF,	},
-	{ "no-precious",		RF_PRECIOUS_OFF, RF_PRECIOUS,		},
+	{ "no-precious",	RF_PRECIOUS_OFF, RF_PRECIOUS,		},
 	{ "noprecious",		RF_PRECIOUS_OFF, RF_PRECIOUS,		},
 	{ "recurse",		RF_RECURSE,	RF_RECURSE_OFF,		},
 	{ "no-recurse",		RF_RECURSE_OFF,	RF_RECURSE,		},
@@ -223,9 +237,25 @@ flag_recognize(slp, pp)
 				scp = sub_context_new();
 				sub_var_set(scp, "Name1", "%S", name);
 				if (odata)
-					sub_var_set(scp, "Name2", "%s", odata->name);
+				{
+					sub_var_set
+					(
+						scp,
+						"Name2",
+						"%s",
+						odata->name
+					);
+				}
 				else
-					sub_var_set(scp, "Name2", "no-%S", name);
+				{
+					sub_var_set
+					(
+						scp,
+						"Name2",
+						"no-%S",
+						name
+					);
+				}
 				error_with_position
 				(
 					pp,
@@ -355,6 +385,11 @@ flag_set_options(fp, level)
 	if (fp->flag[RF_INCLUDE_COOKED_WARNING_OFF])
 		option_set(OPTION_INCLUDE_COOKED_WARNING, level, 0);
 
+	if (fp->flag[RF_INGREDIENTS_FINGERPRINT])
+		option_set(OPTION_INGREDIENTS_FINGERPRINT, level, 1);
+	if (fp->flag[RF_INGREDIENTS_FINGERPRINT_OFF])
+		option_set(OPTION_INGREDIENTS_FINGERPRINT, level, 0);
+
 	if (fp->flag[RF_MATCH_MODE_REGEX])
 		option_set(OPTION_MATCH_MODE_REGEX, level, 1);
 	if (fp->flag[RF_MATCH_MODE_COOK])
