@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -167,7 +167,8 @@ graph_check_ingredients(gp, rp, preference, target, need_gfl,
 	/*
 	 * be optimistic, assume success
 	 */
-	trace(("graph_check_ingredients(gp = %8.8lX, rp = %8.8lX, preference = %d)\n{\n"/*}*/,
+	trace(("graph_check_ingredients(gp = %8.8lX, rp = %8.8lX, \
+preference = %d)\n{\n"/*}*/,
 		(long)gp, (long)rp, (int)preference));
 	ocp = 0;
 	cascade_list_constructor(&cascade);
@@ -192,7 +193,18 @@ graph_check_ingredients(gp, rp, preference, target, need_gfl,
 	string_list_constructor(target);
 	if (mp)
 	{
-		if (match_wl_reconstruct_lhs(mp, target, rp->target, &rp->pos) < 0)
+		if
+		(
+			match_wl_reconstruct_lhs
+			(
+				mp,
+				target,
+				rp->target,
+				&rp->pos
+			)
+		<
+			0
+		)
 		{
 			trace(("return error;\n"));
 			trace((/*{*/"}\n"));
@@ -283,8 +295,11 @@ graph_check_ingredients(gp, rp, preference, target, need_gfl,
 				sub_context_delete(scp);
 			}
 			gp->statistic.precondition_rejection++;
-			goto backtrack;
+			status = graph_build_status_backtrack;
+			trace(("failed\n"));
+			goto done;
 		}
+		trace(("passed\n"));
 	}
 
 	/*
@@ -311,11 +326,13 @@ graph_check_ingredients(gp, rp, preference, target, need_gfl,
 	{
 		string_ty	*target2;
 		graph_build_result_ty result2;
+		edge_type_ty	type2;
 
-		target2 = wlp1->string[k];
+		edge_type_extract(wlp1->string[k], &target2, &type2);
 		if (!os_legal_path(target2))
 		{
 			string_list_delete(wlp1);
+			str_free(target2);
 backtrack:
 			if (option_test(OPTION_REASON))
 			{
@@ -371,10 +388,20 @@ backtrack:
 			 */
 			trace(("mark\n"));
 			mp2 = match_clone(mp);
-			inhibit = match_wl_attempt(mp2, rp->target, target2, &rp->pos);
+			inhibit =
+				match_wl_attempt
+				(
+					mp2,
+					rp->target,
+					target2,
+					&rp->pos
+				);
 			match_delete(mp2);
 			if (inhibit < 0)
+			{
+				str_free(target2);
 				goto error;
+			}
 			if (inhibit)
 			{
 				rp->inhibit = 1;
@@ -413,6 +440,7 @@ backtrack:
 			);
 			sub_context_delete(scp);
 			gp->statistic.error_by_ingredient++;
+			str_free(target2);
 			goto error;
 
 		case graph_build_status_success:
@@ -420,10 +448,12 @@ backtrack:
 			graph_file_list_nrc_append
 			(
 				need_gfl,
-				result2.gfp
+				result2.gfp,
+				type2
 			);
 			break;
 		}
+		str_free(target2);
 	}
 
 	trace(("check second ingredients\n"));
@@ -445,8 +475,9 @@ backtrack:
 	{
 		string_ty	*target2;
 		graph_build_result_ty result2;
+		edge_type_ty	type2;
 
-		target2 = wlp2->string[k];
+		edge_type_extract(wlp2->string[k], &target2, &type2);
 		if (!os_legal_path(target2))
 		{
 			string_list_delete(wlp1);
@@ -480,7 +511,167 @@ backtrack:
 			 */
 			trace(("mark\n"));
 			mp2 = match_clone(mp);
-			inhibit = match_wl_attempt(mp2, rp->target, target2, &rp->pos);
+			inhibit =
+				match_wl_attempt
+				(
+					mp2,
+					rp->target,
+					target2,
+					&rp->pos
+				);
+			match_delete(mp2);
+			if (inhibit < 0)
+			{
+				str_free(target2);
+				goto error;
+			}
+			if (inhibit)
+			{
+				rp->inhibit = 1;
+				gp->statistic.inhibit_self_recursion++;
+			}
+		}
+		option_undo_level(OPTION_LEVEL_RECIPE);
+
+		graph_build_file
+		(
+			gp,
+			target2,
+			graph_build_preference_error,
+			&result2,
+			implicit_allowed
+		);
+
+		recipe_flags_set(rp);
+		switch (result2.status)
+		{
+		case graph_build_status_backtrack:
+			/*
+			 * highly unlikely, especially since we
+			 * said we preferred errors to
+			 * backtracking.
+			 */
+			string_list_delete(wlp1);
+			string_list_delete(wlp2);
+			gp->statistic.backtrack_by_ingredient++;
+			goto backtrack;
+
+		case graph_build_status_error:
+			string_list_delete(wlp1);
+			string_list_delete(wlp2);
+			scp = sub_context_new();
+			sub_var_set(scp, "File_Name1", "%S", target1);
+			sub_var_set(scp, "File_Name2", "%S", target2);
+			error_with_position
+			(
+				&rp->pos,
+				scp,
+	i18n("\"$filename1\" not derived due to errors deriving \"$filename2\"")
+			);
+			sub_context_delete(scp);
+			gp->statistic.error_by_ingredient++;
+			str_free(target2);
+			goto error;
+
+		case graph_build_status_success:
+			string_list_append_unique(&need, target2);
+			graph_file_list_nrc_append
+			(
+				need_gfl,
+				result2.gfp,
+				type2
+			);
+			break;
+		}
+		str_free(target2);
+	}
+
+	/*
+	 * Now add the common ingredients.  This could have been added
+	 * at the start, but users don't expect the common ingredients
+	 * there.  (They seem to read the recipe left-to-right, and
+	 * expect the common ingredients on the end as ``extra''.)
+	 */
+	trace(("mark\n"));
+	if (common_ingredients_gfl)
+	{
+		for (j = 0; j < common_ingredients_gfl->nfiles; ++j)
+		{
+			string_list_append_unique
+			(
+				&need,
+				common_ingredients_gfl->item[j].file->filename
+			);
+		}
+		graph_file_list_nrc_append_list
+		(
+			need_gfl,
+			common_ingredients_gfl
+		);
+	}
+
+	/*
+	 * Find the cascaded ingredients, and add them.
+	 */
+	trace(("mark\n"));
+	if (cascade_enabled)
+		cascade_find(&need, &cascade);
+	for (k = 0; k < cascade.length; ++k)
+	{
+		cascade_ty	*cp;
+		string_ty	*target2;
+		graph_build_result_ty result2;
+		edge_type_ty	type2;
+
+		cp = &cascade.list[k];
+		edge_type_extract(cp->ingredient, &target2, &type2);
+#if 0
+		if (string_list_member(&need, target2))
+		{
+			/* But the edge type could be more strict! */
+			continue;
+		}
+#endif
+		if (!os_legal_path(target2))
+		{
+			string_list_delete(wlp1);
+			string_list_delete(wlp2);
+			gp->statistic.backtrack_bad_path++;
+			goto backtrack;
+		}
+		if (option_test(OPTION_REASON))
+		{
+			scp = sub_context_new();
+			sub_var_set(scp, "File_Name1", "%S", target1);
+			sub_var_set(scp, "File_Name2", "%S", target2);
+			error_with_position
+			(
+				&cp->pos,
+				scp,
+		 	 i18n("\"$filename1\" requires \"$filename2\" (reason)")
+			);
+			sub_context_delete(scp);
+		}
+		if (mp && !option_test(OPTION_RECURSE))
+		{
+			match_ty	*mp2;
+			int		inhibit;
+
+			/*
+			 * if any of the ingredients of an
+			 * implicit recipe match the targets of
+			 * that same recipe, inhibit the
+			 * recursive application the recipe.
+			 */
+			mp2 = match_clone(mp);
+			inhibit =
+				match_wl_attempt
+				(
+					mp2,
+					rp->target,
+					target2,
+					&rp->pos
+				);
 			match_delete(mp2);
 			if (inhibit < 0)
 				goto error;
@@ -536,138 +727,13 @@ backtrack:
 			graph_file_list_nrc_append
 			(
 				need_gfl,
-				result2.gfp
+				result2.gfp,
+				type2
 			);
 			break;
 		}
 	}
 
-	/*
-	 * Now add the common ingredients.  This could have been added
-	 * at the start, but users don't expect the common ingredients
-	 * there.  (They seem to read the recipe left-to-right, and
-	 * expect the common ingredients on the end as ``extra''.)
-	 */
-	trace(("mark\n"));
-	if (common_ingredients_gfl)
-	{
-		for (j = 0; j < common_ingredients_gfl->nfiles; ++j)
-		{
-			string_list_append_unique
-			(
-				&need,
-				common_ingredients_gfl->file[j]->filename
-			);
-		}
-		graph_file_list_nrc_append_list(need_gfl, common_ingredients_gfl);
-	}
-
-	/*
-	 * Find the cascaded ingredients, and add them.
-	 */
-	trace(("mark\n"));
-	if (cascade_enabled)
-		cascade_find(&need, &cascade);
-	for (k = 0; k < cascade.length; ++k)
-	{
-		cascade_ty	*cp;
-		string_ty	*target2;
-		graph_build_result_ty result2;
-
-		cp = &cascade.list[k];
-		target2 = cp->ingredient;
-		if (string_list_member(&need, target2))
-			continue;
-		if (!os_legal_path(target2))
-		{
-			string_list_delete(wlp1);
-			string_list_delete(wlp2);
-			gp->statistic.backtrack_bad_path++;
-			goto backtrack;
-		}
-		if (option_test(OPTION_REASON))
-		{
-			scp = sub_context_new();
-			sub_var_set(scp, "File_Name1", "%S", target1);
-			sub_var_set(scp, "File_Name2", "%S", target2);
-			error_with_position
-			(
-				&cp->pos,
-				scp,
-		 	 i18n("\"$filename1\" requires \"$filename2\" (reason)")
-			);
-			sub_context_delete(scp);
-		}
-		if (mp && !option_test(OPTION_RECURSE))
-		{
-			match_ty	*mp2;
-			int		inhibit;
-
-			/*
-			 * if any of the ingredients of an
-			 * implicit recipe match the targets of
-			 * that same recipe, inhibit the
-			 * recursive application the recipe.
-			 */
-			mp2 = match_clone(mp);
-			inhibit = match_wl_attempt(mp2, rp->target, target2, &rp->pos);
-			match_delete(mp2);
-			if (inhibit < 0)
-				goto error;
-			if (inhibit)
-			{
-				rp->inhibit = 1;
-				gp->statistic.inhibit_self_recursion++;
-			}
-		}
-		option_undo_level(OPTION_LEVEL_RECIPE);
-
-		graph_build_file
-		(
-			gp,
-			target2,
-			graph_build_preference_error,
-			&result2,
-			implicit_allowed
-		);
-
-		recipe_flags_set(rp);
-		switch (result2.status)
-		{
-		case graph_build_status_backtrack:
-			/*
-			 * highly unlikely, especially since we
-			 * said we preferred errors to
-			 * backtracking.
-			 */
-			string_list_delete(wlp1);
-			string_list_delete(wlp2);
-			gp->statistic.backtrack_by_ingredient++;
-			goto backtrack;
-
-		case graph_build_status_error:
-			string_list_delete(wlp1);
-			string_list_delete(wlp2);
-			scp = sub_context_new();
-			sub_var_set(scp, "File_Name1", "%S", target1);
-			sub_var_set(scp, "File_Name2", "%S", target2);
-			error_with_position
-			(
-				&rp->pos,
-				scp,
-	i18n("\"$filename1\" not derived due to errors deriving \"$filename2\"")
-			);
-			sub_context_delete(scp);
-			gp->statistic.error_by_ingredient++;
-			goto error;
-
-		case graph_build_status_success:
-			string_list_append_unique(&need, target2);
-			graph_file_list_nrc_append(need_gfl, result2.gfp);
-			break;
-		}
-	}
-
 	/*
 	 * If there is a precondition and if the gatefirst option is
 	 * not set then check the precondition, now that we have evaluated
@@ -684,7 +750,13 @@ backtrack:
 		 * variable.  (Note: can't define [younger] until we
 		 * walk the graph.)
 		 */
-		opcode_context_id_assign(ocp, id_need, id_variable_new(&need), -1);
+		opcode_context_id_assign
+		(
+			ocp,
+			id_need,
+			id_variable_new(&need),
+			-1
+		);
 
 		/*
 		 * evaluate the predicate
@@ -742,7 +814,7 @@ backtrack:
 			wlp2,
 			&rp->pos
 		);
-		
+
 		/* remember cascaded ingredients */
 		for (j = 0; j < cascade.length; ++j)
 		{
@@ -830,7 +902,8 @@ graph_check_recipe(gp, rp, preference, common_ingredients_gfl, implicit_allowed,
 	size_t		k;
 	opcode_context_ty *ocp;
 
-	trace(("graph_check_recipe(gp = %8.8lX, rp = %8.8lX, preference = %d)\n{\n",
+	trace(("graph_check_recipe(gp = %8.8lX, rp = %8.8lX, \
+preference = %d)\n{\n",
 		(long)gp, (long)rp, (int)preference));
 	ocp = 0;
 	status =
@@ -927,7 +1000,7 @@ graph_check_recipe(gp, rp, preference, common_ingredients_gfl, implicit_allowed,
 			gfp = graph_file_new(fn);
 			symtab_assign(gp->already, fn, gfp);
 		}
-		graph_file_list_nrc_append(grp->output, gfp);
+		graph_file_list_nrc_append(grp->output, gfp, edge_type_default);
 		graph_recipe_list_nrc_append(gfp->input, grp);
 	}
 	string_list_destructor(&target);
@@ -939,12 +1012,17 @@ graph_check_recipe(gp, rp, preference, common_ingredients_gfl, implicit_allowed,
 	trace(("double link list thru need\n"));
 	for (k = 0; k < need_gfl.nfiles; ++k)
 	{
-		graph_file_ty	*gfp;
+		graph_file_and_type_ty *gftp;
 
-		gfp = need_gfl.file[k];
-		trace(("%s\n", gfp->filename->str_text));
-		graph_file_list_nrc_append(grp->input, gfp);
-		graph_recipe_list_nrc_append(gfp->output, grp);
+		gftp = need_gfl.item + k;
+		trace(("%s\n", gftp->file->filename->str_text));
+		graph_file_list_nrc_append
+		(
+			grp->input,
+			gftp->file,
+			gftp->edge_type
+		);
+		graph_recipe_list_nrc_append(gftp->file->output, grp);
 	}
 	graph_file_list_nrc_destructor(&need_gfl);
 
@@ -1067,8 +1145,10 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 	 */
 	graph_file_list_nrc_ty common_ingredients_gfl;
 
-	trace(("graph_build_file(gp = %8.8lX, target = %08lX, preference = %d, result = %8.8lX, imp=%d)\n{\n"/*}*/,
-		(long)gp, (long)target, (int)preference, (long)result, implicit_allowed));
+	trace(("graph_build_file(gp = %8.8lX, target = %08lX, preference = %d, \
+result = %8.8lX, imp=%d)\n{\n"/*}*/,
+		(long)gp, (long)target, (int)preference, (long)result,
+		implicit_allowed));
 	result->status = graph_build_status_error;
 	result->gfp = 0;
 	gfp = 0;
@@ -1275,7 +1355,11 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 			gp->statistic.explicit_ingredients_applicable++;
 			break;
 		}
-		graph_file_list_nrc_append_list(&common_ingredients_gfl, &need2_gfl);
+		graph_file_list_nrc_append_list
+		(
+			&common_ingredients_gfl,
+			&need2_gfl
+		);
 		string_list_destructor(&target2);
 		graph_file_list_nrc_destructor(&need2_gfl);
 		used_ingredients_recipe = 1;
@@ -1349,7 +1433,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 			switch (status2)
 			{
 			case graph_build_status_backtrack:
-				gp->statistic.implicit_ingredients_not_applicable++;
+			    gp->statistic.implicit_ingredients_not_applicable++;
 				continue;
 
 			case graph_build_status_error:
@@ -1360,7 +1444,11 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 				gp->statistic.implicit_ingredients_applicable++;
 				break;
 			}
-			graph_file_list_nrc_append_list(&common_ingredients_gfl, &need2_gfl);
+			graph_file_list_nrc_append_list
+			(
+				&common_ingredients_gfl,
+				&need2_gfl
+			);
 			string_list_destructor(&target2);
 			graph_file_list_nrc_destructor(&need2_gfl);
 			used_ingredients_recipe = 1;
@@ -1425,7 +1513,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 			switch (status2)
 			{
 			case graph_build_status_backtrack:
-				gp->statistic.implicit_ingredients_not_applicable++;
+			    gp->statistic.implicit_ingredients_not_applicable++;
 				continue;
 
 			case graph_build_status_error:
@@ -1436,7 +1524,11 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 				gp->statistic.implicit_ingredients_applicable++;
 				break;
 			}
-			graph_file_list_nrc_append_list(&common_ingredients_gfl, &need2_gfl);
+			graph_file_list_nrc_append_list
+			(
+				&common_ingredients_gfl,
+				&need2_gfl
+			);
 			string_list_destructor(&target2);
 			graph_file_list_nrc_destructor(&need2_gfl);
 			used_ingredients_recipe = 1;
@@ -1563,7 +1655,14 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 				mp = match_new_by_recipe(rp);
 
 				target_pattern = rp->target->string[k];
-				ok = match_attempt(mp, target_pattern, target, &rp->pos);
+				ok =
+					match_attempt
+					(
+						mp,
+						target_pattern,
+						target,
+						&rp->pos
+					);
 				if (ok < 0)
 				{
 					match_delete(mp);
@@ -1580,7 +1679,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 					(
 						gp,
 						rp,
-						graph_build_preference_backtrack,
+					       graph_build_preference_backtrack,
 						&common_ingredients_gfl,
 						implicit_allowed,
 						mp
@@ -1657,7 +1756,14 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 				mp = match_new_by_recipe(rp);
 
 				target_pattern = rp->target->string[k];
-				ok = match_attempt(mp, target_pattern, target, &rp->pos);
+				ok =
+					match_attempt
+					(
+						mp,
+						target_pattern,
+						target,
+						&rp->pos
+					);
 				if (ok < 0)
 				{
 					match_delete(mp);
@@ -1674,7 +1780,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 					(
 						gp,
 						rp,
-						graph_build_preference_backtrack,
+					       graph_build_preference_backtrack,
 						&common_ingredients_gfl,
 						implicit_allowed,
 						mp
@@ -1752,7 +1858,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 			result->status = graph_build_status_error;
 			result->gfp = 0;
 			goto ret;
-		
+
 		case leaf_ness_exterior_explicit:
 			short_cut_exterior:
 			if (option_test(OPTION_REASON))
@@ -1841,8 +1947,8 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 						0,	/* flags */
 						0,	/* multiple */
 						(opcode_list_ty *)0, /* pred */
-						(opcode_list_ty *)0, /* single thread */
-						(opcode_list_ty *)0, /* host binding */
+						(opcode_list_ty *)0, /* sing */
+						(opcode_list_ty *)0, /* host */
 						(opcode_list_ty *)0, /* ood */
 						(opcode_list_ty *)0, /* utd */
 						(expr_position_ty *)0
@@ -1960,7 +2066,7 @@ graph_build_file(gp, target, preference, result, implicit_allowed)
 			(
 				leaf == leaf_ness_leaf_explicit
 			&&
-				cook_mtime_oldest(ocp, target, (long *)0, 32767L) == 0
+			  cook_mtime_oldest(ocp, target, (long *)0, 32767L) == 0
 			)
 			{
 				/*
@@ -2000,7 +2106,11 @@ ret:
 		string_list_append_unique(gp->try_list, target);
 		if (try_list_saved)
 		{
-			string_list_append_list_unique(gp->try_list, try_list_saved);
+			string_list_append_list_unique
+			(
+				gp->try_list,
+				try_list_saved
+			);
 			string_list_delete(try_list_saved);
 		}
 		if (gfp)
@@ -2041,7 +2151,8 @@ ret:
 	/*
 	 * report results for debug
 	 */
-	assert((result->status == graph_build_status_success) == (result->gfp != 0));
+	assert((result->status == graph_build_status_success) ==
+		(result->gfp != 0));
 	trace
 	((
 		"return { %s, %8.8lX};\n",
