@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -536,7 +536,12 @@ now younger (reason)")
 			 * will be up to date before this recipie's body
 			 * is evaluated.  The actual relative ages of the
 			 * ingredient and the target don't come into it.
+			 *
+			 * Also, the depth is not a consideration
+			 * (otherwise this could imply a `set shallow'
+			 * that the user did not intend.
 			 */
+			depth2 = 32767;
 			break;
 
 		case edge_type_weak:
