@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -383,7 +383,7 @@ implications_of_recipe(walk, grp, uptodate)
 	{
 		graph_file_ty	*gfp;
 
-		gfp = grp->output->file[j];
+		gfp = grp->output->item[j].file;
 		implications_of_file(walk, gfp, uptodate);
 	}
 	trace((/*{*/"}\n"));
@@ -436,7 +436,8 @@ graph_walk_inner(gp, func, nproc)
 	itab_ty		*itp;
 	string_list_ty	single_thread;
 
-	trace(("graph_walk(gp = %8.8lX, nproc = %d)\n{\n"/*}*/, (long)gp, nproc));
+	trace(("graph_walk(gp = %8.8lX, nproc = %d)\n{\n"/*}*/,
+		(long)gp, nproc));
 	status = graph_walk_status_uptodate;
 	itp = itab_alloc(nproc);
 
@@ -600,15 +601,23 @@ graph_walk_inner(gp, func, nproc)
 				grp = kp;
 			}
 			trace(("grp = %08lX;\n", (long)grp));
-			trace(("grp->input->nfiles = %ld;\n", (long)grp->input->nfiles));
-			trace(("grp->output->nfiles = %ld;\n", (long)grp->output->nfiles));
+			trace(("grp->input->nfiles = %ld;\n",
+				(long)grp->input->nfiles));
+			trace(("grp->output->nfiles = %ld;\n",
+				(long)grp->output->nfiles));
 
 			/*
 			 * Remember the single threading, so other
 			 * recipes avoid conflicting with *this* one.
 			 */
 			if (grp->single_thread)
-				string_list_append_list(&single_thread, grp->single_thread);
+			{
+				string_list_append_list
+				(
+					&single_thread,
+					grp->single_thread
+				);
+			}
 
 			/*
 			 * run the recipe body
@@ -619,13 +628,21 @@ graph_walk_inner(gp, func, nproc)
 			/*
 			 * Look at what happened.
 			 */
-			if (grp->single_thread && status2 != graph_walk_status_wait)
-				string_list_remove_list(&single_thread, grp->single_thread);
+			if (grp->single_thread && status2 !=
+				graph_walk_status_wait)
+			{
+				string_list_remove_list
+				(
+					&single_thread,
+					grp->single_thread
+				);
+			}
 			switch (status2)
 			{
 			case graph_walk_status_wait:
 				assert(itp);
-				trace(("pid = %d;\n", graph_recipe_getpid(grp)));
+				trace(("pid = %d;\n",
+					graph_recipe_getpid(grp)));
 				itab_assign(itp, graph_recipe_getpid(grp), grp);
 				trace(("itp->load = %ld;\n", (long)itp->load));
 				break;
@@ -644,8 +661,9 @@ graph_walk_inner(gp, func, nproc)
 
 			case graph_walk_status_done_stop:
 				/*
-				 * It worked, but we need to stop for some reason.
-				 * This is usually only used by isit_uptodate.
+				 * It worked, but we need to stop for
+				 * some reason.  This is usually only
+				 * used by isit_uptodate.
 				 */
 				trace(("done_stop\n"));
 				if (status == graph_walk_status_uptodate)
@@ -689,14 +707,14 @@ graph_walk_inner(gp, func, nproc)
 				int		pid;
 				int		exit_status;
 				struct rusage	ru;
-	
+
 				trace(("mark\n"));
 				pid = os_wait3(&exit_status, WNOHANG, &ru);
 				trace(("pid = %d\n", pid));
 				if (pid < 0)
 				{
 					sub_context_ty	*scp;
-	
+
 					if (errno == EINTR)
 						continue;
 					scp = sub_context_new();
@@ -712,12 +730,18 @@ graph_walk_inner(gp, func, nproc)
 					{
 						/* if it's one of ours... */
 						trace(("...waited\n"));
-						assert(pid == graph_recipe_getpid(grp));
+						assert(pid ==
+						      graph_recipe_getpid(grp));
 						if (grp->ocp->rup)
 							*(grp->ocp->rup) = ru;
-						graph_recipe_waited(grp, exit_status);
+						graph_recipe_waited
+						(
+							grp,
+							exit_status
+						);
 						itab_delete(itp, pid);
-						trace(("itp->load = %ld;\n", (long)itp->load));
+						trace(("itp->load = %ld;\n",
+							(long)itp->load));
 						goto run_a_recipe;
 					}
 				}
@@ -901,7 +925,7 @@ graph_walk_pairs(gp)
 	return graph_walk_inner(gp, graph_recipe_pairs, 1);
 }
 
- 
+
 /*
  * NAME
  *	graph_walk_script
