@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -371,7 +371,7 @@ static int
 byte()
 {
 	int		c;
-		
+
 	trace(("byte()\n{\n"/*}*/));
 	for (;;)
 	{
@@ -595,12 +595,12 @@ meta(val)
 			val->m_type = NORMAL;
 			val->m_flag = BEFORE | AFTER;
 			break;
-	
+
 		case EOF:
 			val->m_type = EOF;
 			val->m_flag = SINGLE;
 			break;
-	
+
 		case '+':
 			/*
 			 * processing for += token
@@ -619,7 +619,7 @@ meta(val)
 					break;
 				}
 				/* fall through... */
-	
+
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
@@ -640,7 +640,7 @@ meta(val)
 				val->m_type = NORMAL;
 				val->m_flag = SINGLE;
 				break;
-	
+
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
@@ -649,21 +649,21 @@ meta(val)
 				break;
 			}
 			break;
-	
+
 		case '['/*]*/:
 			switch (mode)
 			{
 			default:
 				val->m_flag = BEFORE | SINGLE;
 				break;
-	
+
 			case LM_SQUOTE:
 			case LM_DQUOTE:
 				val->m_flag = BEFORE | AFTER;
 			}
 			val->m_type = NORMAL;
 				break;
-	
+
 		case /*[*/']':
 			val->m_type = NORMAL;
 			switch (mode)
@@ -671,7 +671,7 @@ meta(val)
 			default:
 				val->m_flag = AFTER | SINGLE;
 				break;
-	
+
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
@@ -679,7 +679,7 @@ meta(val)
 				break;
 			}
 			break;
-	
+
 		case ' ':
 		case '\t':
 		case '\n':
@@ -690,7 +690,7 @@ meta(val)
 				val->m_type = WHITE;
 				val->m_flag = SINGLE;
 				break;
-	
+
 			case LM_SQUOTE:
 			case LM_DQUOTE:
 			case LM_DATA:
@@ -699,19 +699,19 @@ meta(val)
 				break;
 			}
 			break;
-	
+
 		case '\\':
 			switch (val->m_char = byte())
 			{
 			case EOF:
 				illeof();
-	
+
 			case '\n':
 				val->m_char = ' ';
 				val->m_type = WHITE;
 				val->m_flag = SINGLE;
 				break;
-	
+
 			case '0':
 			case '1':
 			case '2':
@@ -723,12 +723,13 @@ meta(val)
 				{
 					int	 count;
 					int	 c;
-	
+
 					c = val->m_char;
 					val->m_char = 0;
 					for (count = 0; count < 3; count++)
 					{
-						val->m_char = val->m_char * 8 + c - '0';
+						val->m_char =
+						      val->m_char * 8 + c - '0';
 						c = byte();
 						if (c < '0' || c > '7')
 						{
@@ -740,12 +741,17 @@ meta(val)
 					val->m_flag = BEFORE | AFTER;
 				}
 				break;
-	
+
 			default:
 				{
 					char	*cp;
-	
-					cp = strchr("b\bf\fn\nr\rt\t", val->m_char);
+
+					cp =
+						strchr
+						(
+							"b\bf\fn\nr\rt\t",
+							val->m_char
+						);
 					if (cp)
 						val->m_char = cp[1];
 					val->m_type = SLOSHED;
@@ -754,79 +760,79 @@ meta(val)
 				break;
 			}
 			break;
-	
+
 		case '/':
-			switch (mode)
-			{
-			default:
-				{
-					int	 c;
-					int	 gate;
-					int	 count;
-	
-					if ((c = byte()) != '*')
-					{
-						byte_undo(c);
-						val->m_type = NORMAL;
-						val->m_flag = BEFORE | AFTER;
-						break;
-					}
-					gate = 0;
-					count = 1;
-					while (count)
-					{
-						switch (c = byte())
-						{
-						default:
-						case '\n':
-						case '\t':
-						case '\f':
-							gate = 0;
-							break;
-	
-						case EOF:
-							illeof();
-	
-						case '*':
-							if (gate == 1)
-							{
-								/*
-								 * nested comment start
-								 *
-								 * should a warning be issued?
-								 */
-								count++;
-								gate = 0;
-							}
-							else
-								gate = 2;
-							break;
-	
-						case '/':
-							if (gate == 2)
-							{
-								count--;
-								gate = 0;
-							}
-							else
-								gate = 1;
-							break;
-						}
-					}
-					val->m_char = ' ';
-					val->m_type = WHITE;
-					val->m_flag = SINGLE;
-				}
-				break;
-	
-			case LM_DATA:
-			case LM_SQUOTE:
-			case LM_DQUOTE:
-				val->m_type = NORMAL;
-				val->m_flag = BEFORE | AFTER;
-				break;
-			}
-			break;
+                        switch (mode)
+                        {
+                        default:
+                            {
+                                int     c;
+                                int     gate;
+                                int     count;
+
+                                if ((c = byte()) != '*')
+                                {
+                                    byte_undo(c);
+                                    val->m_type = NORMAL;
+                                    val->m_flag = BEFORE | AFTER;
+                                    break;
+                                }
+                                gate = 0;
+                                count = 1;
+                                while (count)
+                                {
+                                    switch (c = byte())
+                                    {
+                                    default:
+                                    case '\n':
+                                    case '\t':
+                                    case '\f':
+                                        gate = 0;
+                                        break;
+
+                                    case EOF:
+                                        illeof();
+
+                                    case '*':
+                                        if (gate == 1)
+                                        {
+                                            /*
+                                             * nested comment start
+                                             *
+                                             * should a warning be issued?
+                                             */
+                                            count++;
+                                            gate = 0;
+                                        }
+                                        else
+                                            gate = 2;
+                                        break;
+
+                                    case '/':
+                                        if (gate == 2)
+                                        {
+                                            count--;
+                                            gate = 0;
+                                        }
+                                        else
+                                            gate = 1;
+                                        break;
+                                    }
+                                }
+                                val->m_char = ' ';
+                                val->m_type = WHITE;
+                                val->m_flag = SINGLE;
+                            }
+                            break;
+
+                        case LM_DATA:
+                        case LM_SQUOTE:
+                        case LM_DQUOTE:
+                            val->m_type = NORMAL;
+                            val->m_flag = BEFORE | AFTER;
+                            break;
+                        }
+                        break;
 		}
 	}
 	trace(("*val = %s;\n", meta_repn(val)));
@@ -1074,7 +1080,7 @@ mode_repn(n)
  *
  * DESCRIPTION
  *	The tokenize functionm is used to partition the input stream into
- *	discreet tokens. 
+ *	discreet tokens.
  *
  * CAVEAT
  *	Lex_open must have been called previously.
@@ -1135,7 +1141,13 @@ tokenize()
 		switch (c.m_type)
 		{
 		default:
-			fatal_raw("illegal m_type %d (bug %d)", c.m_type, __LINE__);
+			fatal_raw
+			(
+				"%s: %d: illegal m_type %d (bug)",
+				__FILE__,
+				__LINE__,
+				c.m_type
+			);
 
 		case EOF:
 			if (!root->have_said_eof_token)
@@ -1192,239 +1204,250 @@ tokenize()
 
 		case SLOSHED:
 			{
-				int	 sloshed;
+			    int sloshed;
 
-				sloshed = 0;
-				sa_open(&saroot);
-				if (state == 0)
-					mark = sa_mark(&saroot);
-				for (;;)
+			    sloshed = 0;
+			    sa_open(&saroot);
+			    if (state == 0)
+				mark = sa_mark(&saroot);
+			    for (;;)
+			    {
+				trace
+				((
+				    "%s: %d: state %d, mode %s;\n",
+				    root->filename.logical->str_text,
+				    root->l_line,
+				    state,
+				    mode_repn(mode)
+				));
+				sa_char(&saroot, c.m_char);
+				if (c.m_type == SLOSHED)
 				{
-					trace
-					((
-						"%s: %d: state %d, mode %s;\n",
-						root->filename.logical->str_text,
-						root->l_line,
-						state,
-						mode_repn(mode)
-					));
-					sa_char(&saroot, c.m_char);
-					if (c.m_type == SLOSHED)
-					{
-						sloshed = 1;
-						switch (state)
-						{
-						default:
-							state = 1;
-							break;
+				    sloshed = 1;
+				    switch (state)
+				    {
+				    default:
+					state = 1;
+					break;
 
-						case 11:
-						case 12:
-							/* don't change state */
-							break;
-						}
-					}
-					else
-					{
-						switch (c.m_char)
-						{
-						default:
-							switch (state)
-							{
-							default:
-								state = 1;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case '\n':
-							switch (state)
-							{
-							case 9:
-							case 10:
-								sa_goto(&saroot, mark);
-								parse_lval.lv_word = sa_close(&saroot);
-								state = 0;
-								last.m_flag = 0; /* don't CAT after this */
-								dataended = DATAEND;
-								tok = WORD;
-								goto ret;
-
-							case 11:
-							case 12:
-								/* don't change state */
-								lex_error
-								(
-									0,
-							i18n("newline in quote")
-								);
-								break;
-
-							default:
-								state = 0;
-								mark = sa_mark(&saroot);
-								break;
-							}
-							break;
-
-						case '\'':
-							if (state != 12)
-							{
-								static int	oldmode = LM_SQUOTE;
-
-								oldmode = lex_mode(oldmode);
-								sa_goto(&saroot, sa_mark(&saroot)-1);
-								state = ((state == 11) ? 1 : 11);
-								sloshed = 1;
-							}
-							break;
-
-						case '"':
-							if (state != 11)
-							{
-								static int	oldmode = LM_DQUOTE;
-
-								oldmode = lex_mode(oldmode);
-								sa_goto(&saroot, sa_mark(&saroot)-1);
-								state = ((state == 12) ? 1 : 12);
-								sloshed = 1;
-							}
-							break;
-
-						case ' ':
-						case '\t':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 0:
-							case 2:
-								state = 2;
-								break;
-
-							case 9:
-							case 10:
-								state = 10;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case 'a':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 3:
-							case 5:
-								state++;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case 'd':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 0:
-							case 2:
-								state = 3;
-								break;
-
-							case 8:
-								state = 9;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case 'e':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 6:
-								state = 7;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case 'n':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 7:
-								state = 8;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-
-						case 't':
-							switch (state)
-							{
-							default:
-								state = 1;
-								break;
-
-							case 4:
-								state = 5;
-								break;
-
-							case 11:
-							case 12:
-								break;
-							}
-							break;
-						}
-					}
-					last = c;
-					if (last.m_flag & SINGLE)
-						break;
-					meta(&c);
-					if (c.m_flag & SINGLE)
-					{
-						meta_undo(&c);
-						break;
-					}
+				    case 11:
+				    case 12:
+					/* don't change state */
+					break;
+				    }
 				}
-				parse_lval.lv_word = sa_close(&saroot);
-				if (sloshed)
-					tok = WORD;
 				else
-					tok = UNQUOTED_WORD;
+				{
+				    switch (c.m_char)
+				    {
+				    default:
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case '\n':
+					switch (state)
+					{
+					case 9:
+					case 10:
+					    sa_goto(&saroot, mark);
+					    parse_lval.lv_word =
+					    	sa_close(&saroot);
+					    state = 0;
+					    /* don't CAT after this */
+					    last.m_flag = 0;
+					    dataended = DATAEND;
+					    tok = WORD;
+					    goto ret;
+
+					case 11:
+					case 12:
+					    /* don't change state */
+					    lex_error
+					    (
+						0,
+						i18n("newline in quote")
+					    );
+					    break;
+
+					default:
+					    state = 0;
+					    mark = sa_mark(&saroot);
+					    break;
+					}
+					break;
+
+				    case '\'':
+					if (state != 12)
+					{
+    					    static int	oldmode = LM_SQUOTE;
+
+					    oldmode = lex_mode(oldmode);
+					    sa_goto
+					    (
+					    	&saroot,
+						sa_mark(&saroot) - 1
+					    );
+					    state = ((state == 11) ? 1 : 11);
+					    sloshed = 1;
+					}
+					break;
+
+				    case '"':
+					if (state != 11)
+					{
+					    static int oldmode = LM_DQUOTE;
+
+					    oldmode = lex_mode(oldmode);
+					    sa_goto
+					    (
+						&saroot,
+						sa_mark(&saroot) - 1
+					    );
+					    state = ((state == 12) ? 1 : 12);
+					    sloshed = 1;
+					}
+					break;
+
+				    case ' ':
+				    case '\t':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 0:
+					case 2:
+					    state = 2;
+					    break;
+
+					case 9:
+					case 10:
+					    state = 10;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case 'a':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 3:
+					case 5:
+					    state++;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case 'd':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 0:
+					case 2:
+					    state = 3;
+					    break;
+
+					case 8:
+					    state = 9;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case 'e':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 6:
+					    state = 7;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case 'n':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 7:
+					    state = 8;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+
+				    case 't':
+					switch (state)
+					{
+					default:
+					    state = 1;
+					    break;
+
+					case 4:
+					    state = 5;
+					    break;
+
+					case 11:
+					case 12:
+					    break;
+					}
+					break;
+				    }
+				}
+				last = c;
+				if (last.m_flag & SINGLE)
+					break;
+				meta(&c);
+				if (c.m_flag & SINGLE)
+				{
+					meta_undo(&c);
+					break;
+				}
+			    }
+			    parse_lval.lv_word = sa_close(&saroot);
+			    if (sloshed)
+				tok = WORD;
+			    else
+				tok = UNQUOTED_WORD;
 			}
 			goto ret;
 
@@ -1545,7 +1568,7 @@ parse_lex()
 				if (tok == COLON || tok == COLON2)
 				{
 					parse_lval.lv_position.pos_name =
-						str_copy(root->filename.logical);
+					       str_copy(root->filename.logical);
 					parse_lval.lv_position.pos_line =
 						root->l_line;
 					parse_lval.lv_position.multi =
@@ -1555,7 +1578,7 @@ parse_lex()
 				else if (tok == SEMICOLON)
 				{
 					parse_lval.lv_position.pos_name =
-						str_copy(root->filename.logical);
+					       str_copy(root->filename.logical);
 					parse_lval.lv_position.pos_line =
 						root->l_line;
 					parse_lval.lv_position.multi = 0;
@@ -1565,7 +1588,7 @@ parse_lex()
 					int	winged;
 					meta_ty	last;
 					meta_ty	c;
-	
+
 					/*
 					 * This is a special.  Gobble the rest
 					 * of the line before he starts sucking
@@ -1585,10 +1608,10 @@ parse_lex()
 								c.m_type,
 								__LINE__
 							);
-	
+
 						case EOF:
 							illeof();
-	
+
 						case NORMAL:
 						case SLOSHED:
 							if (!winged)
@@ -1601,7 +1624,7 @@ parse_lex()
 								winged = 1;
 							}
 							continue;
-	
+
 						case WHITE:
 							if (c.m_char != '\n')
 								continue;
