@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,8 +34,10 @@ struct opcode_ty
 };
 
 void opcode_delete _((opcode_ty *));
-opcode_status_ty opcode_execute _((const opcode_ty *, struct opcode_context_ty *));
-opcode_status_ty opcode_script _((const opcode_ty *, struct opcode_context_ty *));
+opcode_status_ty opcode_execute _((const opcode_ty *,
+	struct opcode_context_ty *));
+opcode_status_ty opcode_script _((const opcode_ty *,
+	struct opcode_context_ty *));
 void opcode_disassemble _((const opcode_ty *));
 
 #endif /* COOK_OPCODE_H */
