@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@
 #include <os_interface.h>
 #include <star.h>
 #include <str_list.h>
+#include <tempfilename.h>
 #include <trace.h>
 
 
@@ -138,40 +139,6 @@ id_var_search(ocp, key)
 }
 
 
-static string_ty *temporary_filename _((void));
-
-static string_ty *
-temporary_filename()
-{
-#ifdef __CYGWIN32__
-	/*
-	 * For some reason CygWin32's tmpnam() always produces
-	 * filenames which give ``No such file or directory''
-	 */
-	char		iname[100];
-	static int	nnn;
-
-	sprintf(iname, "t%dp%d.tmp", ++nnn, getpid());
-#else
-	char		iname[L_tmpnam];
-
-	tmpnam(iname);
-#endif
-	return str_from_c(iname);
-}
-
-
-static string_ty *dot_temporary_filename _((void));
-
-static string_ty *
-dot_temporary_filename()
-{
-	static long temp_file_number;
-
-	return str_format(".%d.%ld", getpid(), ++temp_file_number);
-}
-
-
 static void chmod_and_check _((const char *, int));
 
 static void
@@ -319,6 +286,11 @@ spawn(args, input, pid_p, host_binding, ocp)
 		 * the command to be executed.  This deals with various
 		 * weird and obscure $SHELL settings, and it also deals
 		 * with command lines so long that rsh barfs.
+		 *
+		 * Yes, there is a potential race condition here.
+		 * Between writing the script and executing it, we
+		 * could be tricked into executing something else.
+		 * Especially if there is a symlink lying in wait.
 		 */
 		script_fn = dot_temporary_filename();
 		script_fp = fopen_and_check(script_fn->str_text, "w");
@@ -346,6 +318,9 @@ spawn(args, input, pid_p, host_binding, ocp)
 		 * This is the result file.  It is where the remote
 		 * command will stash its exit status.	We seed it with
 		 * failure in case the rsh fails altogether.
+		 *
+		 * And, yes, there is a race conditon and we could be
+		 * lied to if they are quick.
 		 */
 		result_fn = dot_temporary_filename();
 		result_fp = fopen_and_check(result_fn->str_text, "w");
