@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -159,7 +159,8 @@ opcode_context_delete(ocp)
  *
  * SYNOPSIS
  *	opcode_status_ty opcode_context_execute_inner(opcode_context_ty *ocp,
- *		opcode_status_ty (*func)(const opcode_ty *, opcode_context_ty *));
+ *		opcode_status_ty (*func)(const opcode_ty *,
+ *		opcode_context_ty *));
  *
  * DESCRIPTION
  *	The opcode_context_execute_inner function is used to drive the
@@ -376,7 +377,8 @@ opcode_context_call(ocp, olp)
 {
 	opcode_frame_ty	*frame;
 
-	trace(("opcode_context_call(ocp = %08lX, olp = %08lX)\n{\n"/*}*/, (long)ocp, (long)olp));
+	trace(("opcode_context_call(ocp = %08lX, olp = %08lX)\n{\n"/*}*/,
+		(long)ocp, (long)olp));
 	if (ocp->call_stack_length >= ocp->call_stack_maximum)
 	{
 		size_t		nbytes;
