@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -57,8 +57,9 @@ execute(op, icp)
 	/*
 	 * This set 10 specific variables:
 	 *	[arg]	is the complete list of function arguments
-	 *	[1]..[9] are the first nine arguments assigned to their own variables,
-	 *		or assigned empty if there are fewer arguments.
+	 *	[1]..[9] are the first nine arguments assigned to their
+	 *		 own variables, or assigned empty if there are
+	 *		 fewer arguments.
 	 */
 	trace(("opcode_prelude::execute()\n{\n"/*}*/));
 	slp = opcode_context_string_list_pop(icp);
