@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,6 @@
 #include <opcode/touch.h>
 #include <option.h>
 #include <os_interface.h>
-#include <quote.h>
 #include <str_list.h>
 #include <trace.h>
 
@@ -127,7 +126,7 @@ script(op, icp)
 		printf("echo touch");
 		for (j = 0; j < value->nstrings; j++)
 		{
-			s = quote(value->string[j]);
+			s = str_quote_shell(value->string[j]);
 			printf(" %s", s->str_text);
 			str_free(s);
 		}
@@ -138,7 +137,7 @@ script(op, icp)
 		printf("touch");
 		for (j = 0; j < value->nstrings; j++)
 		{
-			s = quote(value->string[j]);
+			s = str_quote_shell(value->string[j]);
 			printf(" %s", s->str_text);
 			str_free(s);
 		}
