@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1996, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -115,7 +115,8 @@ option_already(o, level)
 {
 	int		result;
 
-	trace(("option_already(o = %s, level = %s)\n{\n", option_number_name(o), option_level_name(level)));
+	trace(("option_already(o = %s, level = %s)\n{\n",
+		option_number_name(o), option_level_name(level)));
 	assert((int)o >= 0 && (int)o < (int)OPTION_max);
 	result = (((flag.o_flag[(size_t)o] >> (2 * (int)level)) & 1) != 0);
 	trace(("return %d;\n", result));
@@ -144,7 +145,8 @@ option_undo(o, level)
 	option_number_ty	o;
 	option_level_ty	level;
 {
-	trace(("option_undo(o = %s, level = %s)\n{\n", option_number_name(o), option_level_name(level)));
+	trace(("option_undo(o = %s, level = %s)\n{\n", option_number_name(o),
+		option_level_name(level)));
 	assert((int)o >= 0 && (int)o < (int)OPTION_max);
 	flag.o_flag[(size_t)o] &= ~(3L << (2 * (int)level));
 	trace(("}\n"));
@@ -307,7 +309,7 @@ option_tidy_up()
 			".%src",
 		};
 		int	j;
-	
+
 		/*
 		 * A huge range of alternative default names is given.
 		 * The first found will be used.
@@ -443,38 +445,104 @@ option_number_name(o)
 {
 	switch (o)
 	{
-	case OPTION_ACTION: return "OPTION_ACTION";
-	case OPTION_BOOK: return "OPTION_BOOK";
-	case OPTION_CASCADE: return "OPTION_CASCADE";
-	case OPTION_CMDFILE: return "OPTION_CMDFILE";
-	case OPTION_DISASSEMBLE: return "OPTION_DISASSEMBLE";
-	case OPTION_ERROK: return "OPTION_ERROK";
-	case OPTION_FINGERPRINT: return "OPTION_FINGERPRINT";
-	case OPTION_FINGERPRINT_WRITE: return "OPTION_FINGERPRINT_WRITE";
-	case OPTION_FORCE: return "OPTION_FORCE";
-	case OPTION_GATEFIRST: return "OPTION_GATEFIRST";
-	case OPTION_IMPLICIT_ALLOWED: return "OPTION_IMPLICIT_ALLOWED";
-	case OPTION_INCLUDE_COOKED: return "OPTION_INCLUDE_COOKED";
-	case OPTION_INCLUDE_COOKED_WARNING: return "OPTION_INCLUDE_COOKED_WARNING";
-	case OPTION_INVALIDATE_STAT_CACHE: return "OPTION_INVALIDATE_STAT_CACHE";
-	case OPTION_LOGGING: return "OPTION_LOGGING";
-	case OPTION_METER: return "OPTION_METER";
-	case OPTION_MKDIR: return "OPTION_MKDIR";
-	case OPTION_PERSEVERE: return "OPTION_PERSEVERE";
-	case OPTION_PRECIOUS: return "OPTION_PRECIOUS";
-	case OPTION_REASON: return "OPTION_REASON";
-	case OPTION_RECURSE: return "OPTION_RECURSE";
-	case OPTION_SHALLOW: return "OPTION_SHALLOW";
-	case OPTION_SILENT: return "OPTION_SILENT";
-	case OPTION_STAR: return "OPTION_STAR";
-	case OPTION_STRIP_DOT: return "OPTION_STRIP_DOT";
-	case OPTION_TERMINAL: return "OPTION_TERMINAL";
-	case OPTION_TOUCH: return "OPTION_TOUCH";
-	case OPTION_UNLINK: return "OPTION_UNLINK";
-	case OPTION_UPDATE: return "OPTION_UPDATE";
-	case OPTION_UPDATE_MAX: return "OPTION_UPDATE_MAX";
-	case OPTION_MATCH_MODE_REGEX: return "OPTION_MATCH_MODE_REGEX";
-	case OPTION_max: return "OPTION_max";
+	case OPTION_ACTION:
+		return "OPTION_ACTION";
+
+	case OPTION_BOOK:
+		return "OPTION_BOOK";
+
+	case OPTION_CASCADE:
+		return "OPTION_CASCADE";
+
+	case OPTION_CMDFILE:
+		return "OPTION_CMDFILE";
+
+	case OPTION_DISASSEMBLE:
+		return "OPTION_DISASSEMBLE";
+
+	case OPTION_ERROK:
+		return "OPTION_ERROK";
+
+	case OPTION_FINGERPRINT:
+		return "OPTION_FINGERPRINT";
+
+	case OPTION_FINGERPRINT_WRITE:
+		return "OPTION_FINGERPRINT_WRITE";
+
+	case OPTION_FORCE:
+		return "OPTION_FORCE";
+
+	case OPTION_GATEFIRST:
+		return "OPTION_GATEFIRST";
+
+	case OPTION_IMPLICIT_ALLOWED:
+		return "OPTION_IMPLICIT_ALLOWED";
+
+	case OPTION_INCLUDE_COOKED:
+		return "OPTION_INCLUDE_COOKED";
+
+	case OPTION_INCLUDE_COOKED_WARNING:
+		return "OPTION_INCLUDE_COOKED_WARNING";
+
+	case OPTION_INGREDIENTS_FINGERPRINT:
+		return "OPTION_INGREDIENTS_FINGERPRINT";
+
+	case OPTION_INVALIDATE_STAT_CACHE:
+		return "OPTION_INVALIDATE_STAT_CACHE";
+
+	case OPTION_LOGGING:
+		return "OPTION_LOGGING";
+
+	case OPTION_METER:
+		return "OPTION_METER";
+
+	case OPTION_MKDIR:
+		return "OPTION_MKDIR";
+
+	case OPTION_PERSEVERE:
+		return "OPTION_PERSEVERE";
+
+	case OPTION_PRECIOUS:
+		return "OPTION_PRECIOUS";
+
+	case OPTION_REASON:
+		return "OPTION_REASON";
+
+	case OPTION_RECURSE:
+		return "OPTION_RECURSE";
+
+	case OPTION_SHALLOW:
+		return "OPTION_SHALLOW";
+
+	case OPTION_SILENT:
+		return "OPTION_SILENT";
+
+	case OPTION_STAR:
+		return "OPTION_STAR";
+
+	case OPTION_STRIP_DOT:
+		return "OPTION_STRIP_DOT";
+
+	case OPTION_TERMINAL:
+		return "OPTION_TERMINAL";
+
+	case OPTION_TOUCH:
+		return "OPTION_TOUCH";
+
+	case OPTION_UNLINK:
+		return "OPTION_UNLINK";
+
+	case OPTION_UPDATE:
+		return "OPTION_UPDATE";
+
+	case OPTION_UPDATE_MAX:
+		return "OPTION_UPDATE_MAX";
+
+	case OPTION_MATCH_MODE_REGEX:
+		return "OPTION_MATCH_MODE_REGEX";
+
+	case OPTION_max:
+		break;
 	}
 	return "option number unknown";
 }
