@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001 Peter Miller;
+ *	Copyright (C) 1995-2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #include <ac/errno.h>
 #include <ac/fcntl.h>
 #include <ac/limits.h>
-#include <signal.h>
+#include <ac/signal.h>
 #include <ac/stddef.h>
 #include <ac/stdio.h>
 #include <ac/stdlib.h>
@@ -46,6 +46,7 @@
 #include <os/wait.h>
 #include <stat.cache.h>
 #include <str_list.h>
+#include <tempfilename.h>
 #include <trace.h>
 
 #ifdef HAVE_GETRUSAGE
@@ -802,7 +803,6 @@ os_execute(args, input, errok)
 {
 	int		j;
 	int		fd;
-	char		iname[L_tmpnam];
 	int		retval;
 
 	assert(args);
@@ -811,32 +811,27 @@ os_execute(args, input, errok)
 	fd = -1;
 	if (input)
 	{
+		string_ty	*tfn;
+
 		/*
 		 * He has given a string to be used as input to the command,
 		 * so write it out to a file, and then redirect the input.
 		 */
-#ifdef __CYGWIN32__
-		/*
-		 * For some reason CygWin32's tmpnam() always produces
-		 * filenames which give ``No such file or directory''
-		 */
-		{ static int nnn;
-		sprintf(iname, "t%dp%d.tmp", ++nnn, getpid()); }
-#else
-		tmpnam(iname);
-#endif
-		fd = open(iname, O_RDWR | O_CREAT | O_TRUNC, 0666);
+		tfn = temporary_filename();
+		fd = open(tfn->str_text, O_RDWR | O_CREAT | O_TRUNC, 0666);
 		if (fd < 0)
 		{
-			error_intl_open(iname);
+			error_intl_open(tfn->str_text);
+			str_free(tfn);
 			exec_fails:
 			option_set_errors();
 			retval = -1;
 			goto ret;
 		}
-		if (unlink(iname))
+		if (unlink(tfn->str_text))
 		{
-			error_intl_unlink(iname);
+			error_intl_unlink(tfn->str_text);
+			str_free(tfn);
 			goto exec_fails;
 		}
 		if
@@ -846,9 +841,11 @@ os_execute(args, input, errok)
 			lseek(fd, 0L, SEEK_SET)
 		)
 		{
-			error_intl_write(iname);
+			error_intl_write(tfn->str_text);
+			str_free(tfn);
 			goto exec_fails;
 		}
+		str_free(tfn);
 	}
 
 	for (j = 1; j < args->nstrings; j++)
