@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef COOK_RECIPE_LIST_H
 #define COOK_RECIPE_LIST_H
 
-#include <stddef.h>
+#include <ac/stddef.h>
 #include <main.h>
 
 typedef struct recipe_list_ty recipe_list_ty;
