@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 struct stmt_ty;
 struct expr_list_ty;
 
-struct stmt_ty *stmt_assign_new _((struct expr_list_ty *, struct expr_list_ty *));
+struct stmt_ty *stmt_assign_new _((struct expr_list_ty *,
+	struct expr_list_ty *));
 
 #endif /* COOK_STMT_ASSIGN_H */
