@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -83,11 +83,11 @@ main(argc, argv)
 	case arglex_token_help:
 		help((char *)0, usage);
 		exit(0);
-	
+
 	case arglex_token_version:
 		version();
 		exit(0);
-	
+
 	default:
 		break;
 	}
@@ -138,7 +138,11 @@ main(argc, argv)
 			else
 			{
 				too_many:
-				error_intl(0, i18n("too many filenames specified"));
+				error_intl
+				(
+					0,
+					i18n("too many filenames specified")
+				);
 				usage();
 			}
 			break;
