@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1998, 1999 Peter Miller;
+ *	Copyright (C) 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -435,7 +435,11 @@ sniff(ifn, ofn)
 		fprintf(ofp, "\t%s\n", filename->str_text);
 	}
 	fprintf(ofp, "\t;\n");
-	fprintf(ofp, "all_files_in_[.cook.bom.dir] = [files_in_[.cook.bom.dir]];\n");
+	fprintf
+	(
+		ofp,
+		"all_files_in_[.cook.bom.dir] = [files_in_[.cook.bom.dir]];\n"
+	);
 	fflush_and_check(ofp, ofn);
 
 	/*
@@ -449,7 +453,11 @@ sniff(ifn, ofn)
 		fprintf(ofp, "\t%s\n", filename->str_text);
 	}
 	fprintf(ofp, "\t;\n");
-	fprintf(ofp, "all_specials_in_[.cook.bom.dir] = [specials_in_[.cook.bom.dir]];\n");
+	fprintf
+	(
+		ofp,
+	    "all_specials_in_[.cook.bom.dir] = [specials_in_[.cook.bom.dir]];\n"
+	);
 	fflush_and_check(ofp, ofn);
 
 	/*
@@ -463,7 +471,11 @@ sniff(ifn, ofn)
 		fprintf(ofp, "\t%s\n", filename->str_text);
 	}
 	fprintf(ofp, "\t;\n");
-	fprintf(ofp, "all_directories_in_[.cook.bom.dir] = [directories_in_[.cook.bom.dir]];\n");
+	fprintf
+	(
+		ofp,
+      "all_directories_in_[.cook.bom.dir] = [directories_in_[.cook.bom.dir]];\n"
+	);
 	fflush_and_check(ofp, ofn);
 
 	/*
@@ -490,7 +502,11 @@ sniff(ifn, ofn)
  * These variables must be calculated again, as the above includes will\n\
  * have over-written them, and they all use the same variables.\n\
  */\n");
-		fprintf(ofp, ".cook.bom.dir = [relative_dirname [__FILE__]];\n");
+		fprintf
+		(
+			ofp,
+			".cook.bom.dir = [relative_dirname [__FILE__]];\n"
+		);
 		fprintf(ofp, "if [in [.cook.bom.dir] \".\"] then\n");
 		fprintf(ofp, "	.cook.bom/dir = '';\n");
 		fprintf(ofp, "else\n");
@@ -508,7 +524,9 @@ sniff(ifn, ofn)
 		fprintf
 		(
 			ofp,
-			"if [defined all_files_in_[.cook.bom/dir]%s] then\n\tall_files_in_[.cook.bom.dir] +=\n\t\t[addprefix %s/ [all_files_in_[.cook.bom/dir]%s]];\n",
+"if [defined all_files_in_[.cook.bom/dir]%s] then\n\
+\tall_files_in_[.cook.bom.dir] +=\n\
+\t\t[addprefix %s/ [all_files_in_[.cook.bom/dir]%s]];\n",
 			filename->str_text,
 			filename->str_text,
 			filename->str_text
@@ -517,7 +535,9 @@ sniff(ifn, ofn)
 		fprintf
 		(
 			ofp,
-			"if [defined all_specials_in_[.cook.bom/dir]%s] then\n\tall_specials_in_[.cook.bom.dir] +=\n\t\t[addprefix %s/ [all_specials_in_[.cook.bom/dir]%s]];\n",
+"if [defined all_specials_in_[.cook.bom/dir]%s] then\n\
+\tall_specials_in_[.cook.bom.dir] +=\n\
+\t\t[addprefix %s/ [all_specials_in_[.cook.bom/dir]%s]];\n",
 			filename->str_text,
 			filename->str_text,
 			filename->str_text
@@ -526,7 +546,9 @@ sniff(ifn, ofn)
 		fprintf
 		(
 			ofp,
-			"if [defined all_directories_in_[.cook.bom/dir]%s] then\n\tall_directories_in_[.cook.bom.dir] +=\n\t\t[addprefix %s/ [all_directories_in_[.cook.bom/dir]%s]];\n",
+"if [defined all_directories_in_[.cook.bom/dir]%s] then\n\
+\tall_directories_in_[.cook.bom.dir] +=\n\
+\t\t[addprefix %s/ [all_directories_in_[.cook.bom/dir]%s]];\n",
 			filename->str_text,
 			filename->str_text,
 			filename->str_text
