@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2001 Peter Miller;
+#	Copyright (C) 1993-1997, 1999, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -61,7 +61,8 @@ case $file in
 	echo "	\$(YACC) -d $file"
 	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e '/#include.<stdio.h>/d' \
 			y.tab.c > ${stem}.gen.c"
-	echo "	sed -e 's/[yY][yY]/${yy}_/g' y.tab.h > ${stem}.gen.h"
+	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e 's/Y_TAB_H/${yy}_TAB_H/g' \
+			y.tab.h > ${stem}.gen.h"
 	echo "	rm y.tab.c y.tab.h"
 
 	if [ -n "$depfile" -a -r "$depfile" ]; then
@@ -218,7 +219,19 @@ test/*/*.sh)
 	root=`basename $file .sh`
 	echo ""
 	echo "$root: $file all"
-	echo "	CC=\$(CC) \$(SH) $file"
+	echo "	CC=\"\$(CC)\" \$(SH) $file"
+	;;
+
+script/*.in)
+	prog=`echo $file | sed 's|^script/\(.*\)[.]in$|\1|'`
+	echo ""
+	echo "bin/$prog\$(EXEEXT): $file .bin"
+	echo "	CONFIG_FILES=\$@:$file CONFIG_HEADERS= ./config.status"
+	echo "	chmod a+rx \$@"
+	echo ""
+echo "\$(bindir)/\$(PROGRAM_PREFIX)${prog}\$(PROGRAM_SUFFIX)\$(EXEEXT): \
+bin/${prog}\$(EXEEXT) .bindir"
+	echo "	\$(INSTALL_SCRIPT) bin/${prog}\$(EXEEXT) \$@"
 	;;
 
 *)
