@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -160,7 +160,7 @@ main(argc, argv)
 		default:
 			generic_argument(usage);
 			continue;
-	
+
 		case arglex_token_search:
 			if (arglex() != arglex_token_string)
 			{
@@ -201,7 +201,13 @@ main(argc, argv)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set(scp, "Name", "%s", arglex_value.alv_string);
+				sub_var_set
+				(
+					scp,
+					"Name",
+					"%s",
+					arglex_value.alv_string
+				);
 				fatal_intl
 				(
 					scp,
@@ -210,7 +216,7 @@ main(argc, argv)
 			}
 			npaths -= nsyspaths;
 			break;
-	
+
 		case arglex_token_path:
 			if (arglex() != arglex_token_string)
 			{
