@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1994, 1997, 1998 Peter Miller;
+#	Copyright (C) 1994, 1997, 1998, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -72,13 +72,22 @@ if test $? -ne 0 ; then fail; fi
 $bin/cookfp test.in - test.in < test.in > test.out
 if test $? -ne 0 ; then fail; fi
 
-cat > test.ok << 'fubar'
-JoXEhdflGxZdS89tDd5zpFx0JRJyX0k67EH0Jod7aet4hIjB.hGhon0veN0BZRfi058HZQ06U0JD	test.in
-JoXEhdflGxZdS89tDd5zpFx0JRJyX0k67EH0Jod7aet4hIjB.hGhon0veN0BZRfi058HZQ06U0JD	stdin
-JoXEhdflGxZdS89tDd5zpFx0JRJyX0k67EH0Jod7aet4hIjB.hGhon0veN0BZRfi058HZQ06U0JD	test.in
+cat > test.ok.uue << 'fubar'
+begin 644 test.ok
+M2F]816AD9FQ'>%ID4S@Y=$1D-7IP1G@P2E)*>5@P:S8W14@P2F]D-V%E=#1H
+M26I"+FA':&]N,'9E3C!"6E)F:3`U.$A:43`V53!*1`ET97-T+FEN"DIO6$5H
+M9&9L1WA:9%,X.71$9#5Z<$9X,$I22GE8,&LV-T5(,$IO9#=A970T:$EJ0BYH
+M1VAO;C!V94XP0EI29FDP-3A(6E$P-E4P2D0)<W1D:6X*2F]816AD9FQ'>%ID
+M4S@Y=$1D-7IP1G@P2E)*>5@P:S8W14@P2F]D-V%E=#1H26I"+FA':&]N,'9E
+<3C!"6E)F:3`U.$A:43`V53!*1`ET97-T+FEN"@``
+`
+end
 fubar
 if test $? -ne 0 ; then fail; fi
 
+uudecode test.ok.uue
+if test $? -ne 0 ; then fail; fi
+
 diff test.ok test.out
 if test $? -ne 0 ; then fail; fi
 
