@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1997, 1998 Peter Miller;
+#	Copyright (C) 1997, 1998, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -95,7 +95,7 @@ prog: a.o b.o c.o
 	echo [need] > [target];
 }
 
-a.o: a.h b.h c.h;
+a.o: a.h b.h c.h(weak);
 b.o: b.h c.h;
 c.o: c.h;
 fubar
@@ -143,46 +143,46 @@ if test $? -ne 0 ; then fail; fi
 cat > test.ok << 'fubar'
 #!/bin/sh
 
-#line 12 "howto.cook"
+#line 12 howto.cook
 if test ! -e a.o \
-	-o a.c -nt a.o \
-	-o a.h -nt a.o \
-	-o b.h -nt a.o \
+	-o ! a.o -nt a.c \
+	-o ! a.o -nt a.h \
+	-o ! a.o -nt b.h \
 	-o c.h -nt a.o
 then
-echo "echo a.c + a.c a.h b.h c.h > a.o"
+echo 'echo a.c + a.c a.h b.h c.h > a.o'
 ( echo a.c + a.c a.h b.h c.h > a.o )
 test $? -eq 0 || exit 1
 fi
 
-#line 12 "howto.cook"
+#line 12 howto.cook
 if test ! -e b.o \
-	-o b.c -nt b.o \
-	-o b.h -nt b.o \
-	-o c.h -nt b.o
+	-o ! b.o -nt b.c \
+	-o ! b.o -nt b.h \
+	-o ! b.o -nt c.h
 then
-echo "echo b.c + b.c b.h c.h > b.o"
+echo 'echo b.c + b.c b.h c.h > b.o'
 ( echo b.c + b.c b.h c.h > b.o )
 test $? -eq 0 || exit 1
 fi
 
-#line 12 "howto.cook"
+#line 12 howto.cook
 if test ! -e c.o \
-	-o c.c -nt c.o \
-	-o c.h -nt c.o
+	-o ! c.o -nt c.c \
+	-o ! c.o -nt c.h
 then
-echo "echo c.c + c.c c.h > c.o"
+echo 'echo c.c + c.c c.h > c.o'
 ( echo c.c + c.c c.h > c.o )
 test $? -eq 0 || exit 1
 fi
 
-#line 17 "howto.cook"
+#line 17 howto.cook
 if test ! -e prog \
-	-o a.o -nt prog \
-	-o b.o -nt prog \
-	-o c.o -nt prog
+	-o ! prog -nt a.o \
+	-o ! prog -nt b.o \
+	-o ! prog -nt c.o
 then
-echo "echo a.o b.o c.o > prog"
+echo 'echo a.o b.o c.o > prog'
 ( echo a.o b.o c.o > prog )
 test $? -eq 0 || exit 1
 fi
