@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1998 Peter Miller;
+#	Copyright (C) 1998, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -113,18 +113,18 @@ if test $? -ne 0 ; then cat LOG; fail; fi
 cat > test.ok << fubar
 #!/bin/sh
 
-#line 5 "howto.cook"
+#line 5 howto.cook
 if test ! -e fred.o \\
-	-o fred.c -nt fred.o \\
-	-o fred.h -nt fred.o \\
-	-o test.h -nt fred.o
+	-o ! fred.o -nt fred.c \\
+	-o ! fred.o -nt fred.h \\
+	-o ! fred.o -nt test.h
 then
-echo "${CC} -c fred.c"
+echo '${CC} -c fred.c'
 ( ${CC} -c fred.c )
 test \$? -eq 0 || exit 1
 fi
 if test ! -e test \\
-	-o fred.o -nt test
+	-o ! test -nt fred.o
 then
 fi
 exit 0
